## 0.0.9 - 2022-02-05

### Added

- [#155](https://github.com/edgarrmondragon/citric/pull/155) Experimental support Python 3.11
- [#165](https://github.com/edgarrmondragon/citric/pull/165) Test in Windows and MacOS

### Removed

- [#151](https://github.com/edgarrmondragon/citric/pull/151) Drop support for Python 3.6
